@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "magit-pre-commit" "0.1.0"
+(define-package "magit-pre-commit" "20260125.2259"
   "Magit integration for pre-commit."
   '((emacs "29.1")
     (magit "3.0.0")
